DefaultEmojis class
Default emoji presets bundled with the package.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited
Static Properties
-
all
→ List<
EmojiItem> -
All default emojis as a list.
no setter
- none → EmojiItem
-
None/neutral emoji
final
- party → EmojiItem
-
Party emoji (celebration)
final
- partyBlob → EmojiItem
-
Party blob emoji
final
- partyParrot → EmojiItem
-
Party parrot emoji
final
-
partySet
→ List<
EmojiItem> -
Party-themed emojis.
no setter
- pet → EmojiItem
-
Pet emoji
final
- shakeGrab → EmojiItem
-
Shake/grab emoji
final