EmojiSelectorController class
Controller for programmatically managing the emoji selector.
Use this controller to show, hide, or toggle the emoji selector programmatically.
Example:
final controller = EmojiSelectorController();
// Later...
controller.show();
controller.hide();
controller.toggle();
// Check state
if (controller.isShowing) { ... }
// Don't forget to dispose
controller.dispose();
- Inheritance
-
- Object
- ChangeNotifier
- EmojiSelectorController
Constructors
- EmojiSelectorController()
- Creates an EmojiSelectorController.
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- hasListeners → bool
-
Whether any listeners are currently registered.
no setterinherited
- isShowing → bool
-
Whether the selector is currently visible.
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
addListener(
VoidCallback listener) → void -
Register a closure to be called when the object changes.
inherited
-
attach(
{required VoidCallback onShow, required VoidCallback onHide}) → void - Attach callbacks (called internally by EmojiSelector).
-
detach(
) → void - Detach callbacks (called on dispose).
-
dispose(
) → void -
Discards any resources used by the object. After this is called, the
object is not in a usable state and should be discarded (calls to
addListener will throw after the object is disposed).
override
-
hide(
) → void - Hide the emoji selector.
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
notifyListeners(
) → void -
Call all the registered listeners.
inherited
-
removeListener(
VoidCallback listener) → void -
Remove a previously registered closure from the list of closures that are
notified when the object changes.
inherited
-
show(
) → void - Show the emoji selector.
-
toggle(
) → void - Toggle the emoji selector visibility.
-
toString(
) → String -
A string representation of this object.
inherited
-
updateState(
bool isShowing) → void - Update internal state (called by EmojiSelector).
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited